@@ -3,10 +3,11 @@ class _configuration(type):
     def __getattr__(name):
         value = None
         if hasattr(configuration.config, name):
-            value = getattr(configuration.config, name).format(appPath=configuration.appPath)
+            value = getattr(configuration.config, name)
         elif hasattr(configuration.default, name):
-            value = getattr(configuration.default, name).format(appPath=configuration.appPath)
-        return value
+            value = getattr(configuration.default, name)
+        return value.format(appPath=configuration.appPath) if isinstance(value, str) else value
+
 
 class configuration(metaclass=_configuration):
     __metaclass__ = _configuration
@@ -17,6 +18,7 @@ class configuration(metaclass=_configuration):
         configuration.default = deflautConfig()
         configuration.appPath = appPath
 
+
 class deflautConfig:
 
     middleware_list = []
@@ -33,7 +35,11 @@ class deflautConfig:
 
     filter_list = []
 
-    core = "*"
+    service_path = "{appPath}/service"
+
+    util_path = "{appPath}/util"
+
+    cors = "http://localhost"
 
     cookie_id = "alauda_app_id"
 
@@ -41,4 +47,4 @@ class deflautConfig:
 
     router_controller = "home"
 
-    router_action = "index"
\ No newline at end of file
+    router_action = "index"
