@@ -74,12 +74,15 @@ class controller():
         return self.application.get_cookie(name)
 
     def __getattr__(self, name):
-        value = self.application.get_argument(name)
+        value = None
         try:
+            value = self.application.get_argument(name)
             return self.json_decode(value)
         except:
-            return value
-        
+            body = self.json_decode(self.application.request.body)
+            value = body[name] if name in body else None
+        return value
+
     def set_status(self, code, message):
         self.application.set_status(code, message)
         if code >= 400:
